@@ -1,54 +1,62 @@
 """Module for callable ASTx."""
+
 from __future__ import annotations
 
-from typing import cast
+from typing import Optional, cast
 
 from public import public
 
 from astx.base import (
+    NO_SOURCE_LOCATION,
     ASTKind,
+    ASTNodes,
     DataType,
-    Expr,
     ExprType,
-    ReprStruct,
     SourceLocation,
     StatementType,
 )
 from astx.blocks import Block
 from astx.modifiers import ScopeKind, VisibilityKind
-from astx.variables import Argument
+from astx.types import ReprStruct
+from astx.variables import Arguments
 
 
 @public
-class FunctionCall(Expr):
+class FunctionCall(DataType):
     """AST class for function call."""
 
+    fn: Function
+    args: tuple[DataType, ...]
+
     def __init__(
         self,
-        callee: str,
+        fn: Function,
         args: tuple[DataType, ...],
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
     ) -> None:
         """Initialize the Call instance."""
-        super().__init__(loc)
-        self.callee = callee
+        super().__init__(loc=loc, parent=parent)
+        self.fn = fn
         self.args = args
         self.kind = ASTKind.CallKind
 
     def __str__(self) -> str:
         """Return a string representation of the object."""
         args = [str(arg) for arg in self.args]
-        return f"Call[{self.callee}: {', '.join(args)}]"
+        return f"Call[{self.fn}: {', '.join(args)}]"
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Return the AST structure of the object."""
         call_args = []
 
         for node in self.args:
-            call_args.append(node.get_struct())
+            call_args.append(node.get_struct(simplified))
 
-        call_node = {f"FUNCTION-CALL[{self.callee}]": {"args": call_args}}
-        return cast(ReprStruct, call_node)
+        key = f"FUNCTION-CALL[{self.fn}]"
+        value = cast(ReprStruct, {"args": call_args})
+
+        return self._prepare_struct(key, value, simplified)
 
 
 @public
@@ -56,7 +64,7 @@ class FunctionPrototype(StatementType):
     """AST class for function prototype declaration."""
 
     name: str
-    args: tuple[Argument, ...]
+    args: Arguments
     return_type: ExprType
     scope: ScopeKind
     visibility: VisibilityKind
@@ -64,13 +72,15 @@ class FunctionPrototype(StatementType):
     def __init__(
         self,
         name: str,
-        args: tuple[Argument, ...],
+        args: Arguments,
         return_type: ExprType,
         scope: ScopeKind = ScopeKind.global_,
         visibility: VisibilityKind = VisibilityKind.public,
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
     ) -> None:
         """Initialize the FunctionPrototype instance."""
+        super().__init__(loc=loc, parent=parent)
         self.name = name
         self.args = args
         self.return_type = return_type
@@ -79,7 +89,7 @@ class FunctionPrototype(StatementType):
         self.scope = scope
         self.visibility = visibility
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Get the AST structure that represent the object."""
         raise Exception("Visitor method not necessary")
 
@@ -91,10 +101,13 @@ class FunctionReturn(StatementType):
     value: DataType
 
     def __init__(
-        self, value: DataType, loc: SourceLocation = SourceLocation(0, 0)
+        self,
+        value: DataType,
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
     ) -> None:
         """Initialize the Return instance."""
-        self.loc = loc
+        super().__init__(loc=loc, parent=parent)
         self.value = value
         self.kind = ASTKind.ReturnKind
 
@@ -102,9 +115,11 @@ class FunctionReturn(StatementType):
         """Return a string representation of the object."""
         return f"Return[{self.value}]"
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Return the AST structure of the object."""
-        return {"RETURN": self.value.get_struct()}
+        key = "RETURN"
+        value = self.value.get_struct(simplified)
+        return self._prepare_struct(key, value, simplified)
 
 
 @public
@@ -118,10 +133,11 @@ class Function(StatementType):
         self,
         prototype: FunctionPrototype,
         body: Block,
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
     ) -> None:
         """Initialize the Function instance."""
-        self.loc = loc
+        super().__init__(loc=loc, parent=parent)
         self.prototype = prototype
         self.body = body
         self.kind = ASTKind.FunctionKind
@@ -138,27 +154,26 @@ class Function(StatementType):
     def __call__(
         self,
         args: tuple[DataType, ...],
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
     ) -> FunctionCall:
-        """Return a FunctionCall for this call operation."""
-        return FunctionCall(
-            self.prototype.name,
-            args,
-            loc,
-        )
+        """Initialize the Call instance."""
+        return FunctionCall(fn=self, args=args, loc=loc, parent=parent)
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Get the AST structure that represent the object."""
-        fn_args = []
-        for arg in self.prototype.args:
-            fn_args.append(arg.get_struct())
+        fn_args = self.prototype.args.get_struct(simplified)
+        fn_body = self.body.get_struct(simplified)
 
-        fn_body = self.body.get_struct()
+        key = f"FUNCTION[{self.prototype.name}]"
+        args_struct = self._prepare_struct("args", fn_args, simplified)
+        body_struct = self._prepare_struct("body", fn_body, simplified)
 
-        node = {
-            f"FUNCTION[{self.prototype.name}]": {
-                "args": fn_args,
-                "body": fn_body,
-            }
-        }
-        return cast(ReprStruct, node)
+        if not isinstance(args_struct, dict):
+            raise Exception("`args` struct is not a valid object.")
+
+        if not isinstance(body_struct, dict):
+            raise Exception("`body` struct is not a valid object.")
+
+        value: ReprStruct = {**args_struct, **body_struct}
+        return self._prepare_struct(key, value, simplified)
