@@ -1,17 +1,20 @@
 """ASTx Data Types module."""
+
 from __future__ import annotations
 
 from typing import Any
+from uuid import uuid4
 
 from public import public
 
 from astx.base import (
+    NO_SOURCE_LOCATION,
     ASTKind,
     DataType,
     ExprType,
-    ReprStruct,
     SourceLocation,
 )
+from astx.types import ReprStruct
 
 # Operators
 
@@ -20,18 +23,22 @@ from astx.base import (
 class DataTypeOps(DataType):
     """Overload some magic functions used for the main operations."""
 
+    def __hash__(self) -> int:
+        """Ensure that the hash method is not None."""
+        return super().__hash__()
+
     def __add__(self, other: DataType) -> BinaryOp:
         """Overload the magic `add` method."""
         return BinaryOp("+", self, other)
 
-    def __div__(self, other: DataType) -> BinaryOp:
-        """Overload the magic `div` method."""
-        return BinaryOp("/", self, other)
-
     def __eq__(self, other: DataType) -> BinaryOp:  # type: ignore
         """Overload the magic `eq` method."""
         return BinaryOp("==", self, other)
 
+    def __floordiv__(self, other: DataType) -> BinaryOp:
+        """Overload the magic `floordiv` method."""
+        return BinaryOp("//", self, other)
+
     def __ge__(self, other: DataType) -> BinaryOp:
         """Overload the magic `ge` method."""
         return BinaryOp(">=", self, other)
@@ -61,8 +68,12 @@ class DataTypeOps(DataType):
         return BinaryOp("!=", self, other)
 
     def __neg__(self) -> UnaryOp:
-        """Overload the magic `ne` method."""
-        return UnaryOp("!", self)
+        """Overload the magic `neg` method."""
+        return UnaryOp("-", self)
+
+    def __pos__(self) -> UnaryOp:
+        """Overload the magic `pos` method."""
+        return UnaryOp("+", self)
 
     def __pow__(self, other: DataType) -> BinaryOp:
         """Overload the magic `pow` method."""
@@ -85,7 +96,7 @@ class UnaryOp(DataTypeOps):
         self,
         op_code: str,
         operand: DataType,
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
     ) -> None:
         """Initialize the UnaryOp instance."""
         super().__init__()
@@ -98,9 +109,11 @@ class UnaryOp(DataTypeOps):
         """Return a string that represents the object."""
         return f"UnaryOp[{self.op_code}]({self.operand})"
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Return the AST structure of the object."""
-        return {f"UNARY[{self.op_code}]": self.operand.get_struct()}
+        key = f"UNARY[{self.op_code}]"
+        value = self.operand.get_struct(simplified)
+        return self._prepare_struct(key, value, simplified)
 
 
 @public
@@ -114,7 +127,7 @@ class BinaryOp(DataTypeOps):
         op_code: str,
         lhs: DataType,
         rhs: DataType,
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
     ) -> None:
         """Initialize the BinaryOp instance."""
         super().__init__()
@@ -144,14 +157,24 @@ class BinaryOp(DataTypeOps):
         """Return a string that represents the object."""
         return f"BinaryOp[{self.op_code}]({self.lhs},{self.rhs})"
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Return the AST structure that represents the object."""
-        return {
-            f"BINARY[{self.op_code}]": {
-                "lhs": self.lhs.get_struct(),
-                "rhs": self.rhs.get_struct(),
-            }
-        }
+        key = f"BINARY[{self.op_code}]"
+        lhs_struct = self._prepare_struct(
+            "lhs", self.lhs.get_struct(simplified), simplified
+        )
+        rhs_struct = self._prepare_struct(
+            "rhs", self.rhs.get_struct(simplified), simplified
+        )
+
+        if not isinstance(lhs_struct, dict):
+            raise Exception("`lhs` struct is not a valid object.")
+
+        if not isinstance(rhs_struct, dict):
+            raise Exception("`rhs` struct is not a valid object.")
+
+        value: ReprStruct = {**lhs_struct, **rhs_struct}
+        return self._prepare_struct(key, value, simplified)
 
 
 # Data Types
@@ -238,14 +261,20 @@ class Literal(DataTypeOps):
     loc: SourceLocation
     value: Any
 
+    def __init__(self, *args, **kwargs) -> None:  # type: ignore
+        super().__init__(*args, **kwargs)
+        self.ref = uuid4().hex
+
     def __str__(self) -> str:
         """Return a string that represents the object."""
         klass = self.__class__.__name__
         return f"{klass}({self.value})"
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Return the AST representation for the object."""
-        return {f"Literal[{self.type_}]": self.value}
+        key = f"Literal[{self.type_}]: {self.value}"
+        value = self.value
+        return self._prepare_struct(key, value, simplified)
 
 
 @public
@@ -255,7 +284,7 @@ class LiteralInt8(Literal):
     value: int
 
     def __init__(
-        self, value: int, loc: SourceLocation = SourceLocation(0, 0)
+        self, value: int, loc: SourceLocation = NO_SOURCE_LOCATION
     ) -> None:
         """Initialize LiteralInt8."""
         super().__init__(loc)
@@ -271,7 +300,7 @@ class LiteralInt16(Literal):
     value: int
 
     def __init__(
-        self, value: int, loc: SourceLocation = SourceLocation(0, 0)
+        self, value: int, loc: SourceLocation = NO_SOURCE_LOCATION
     ) -> None:
         """Initialize LiteralInt16."""
         super().__init__(loc)
@@ -287,7 +316,7 @@ class LiteralInt32(Literal):
     value: int
 
     def __init__(
-        self, value: int, loc: SourceLocation = SourceLocation(0, 0)
+        self, value: int, loc: SourceLocation = NO_SOURCE_LOCATION
     ) -> None:
         """Initialize LiteralInt32."""
         super().__init__(loc)
@@ -303,7 +332,7 @@ class LiteralInt64(Literal):
     value: int
 
     def __init__(
-        self, value: int, loc: SourceLocation = SourceLocation(0, 0)
+        self, value: int, loc: SourceLocation = NO_SOURCE_LOCATION
     ) -> None:
         """Initialize LiteralInt64."""
         super().__init__(loc)
@@ -319,7 +348,7 @@ class LiteralBoolean(Literal):
     value: bool
 
     def __init__(
-        self, value: bool, loc: SourceLocation = SourceLocation(0, 0)
+        self, value: bool, loc: SourceLocation = NO_SOURCE_LOCATION
     ) -> None:
         """Initialize LiteralBoolean."""
         super().__init__(loc)
