@@ -1,21 +1,24 @@
 """Module for Variables."""
+
 from __future__ import annotations
 
-from typing import cast
+from typing import Any, Optional, cast
 
 from public import public
 
 from astx.base import (
+    NO_SOURCE_LOCATION,
     ASTKind,
+    ASTNodes,
     Expr,
     ExprType,
-    ReprStruct,
     SourceLocation,
     StatementType,
     Undefined,
 )
 from astx.modifiers import MutabilityKind, ScopeKind, VisibilityKind
 from astx.operators import DataTypeOps
+from astx.types import ReprStruct
 
 UNDEFINED = Undefined()
 
@@ -39,10 +42,11 @@ class VariableDeclaration(StatementType):
         visibility: VisibilityKind = VisibilityKind.public,
         scope: ScopeKind = ScopeKind.local,
         value: Expr = UNDEFINED,
-        loc: SourceLocation = SourceLocation(0, 0),
+        parent: Optional[ASTNodes] = None,
+        loc: SourceLocation = NO_SOURCE_LOCATION,
     ) -> None:
         """Initialize the VarExprAST instance."""
-        self.loc = loc
+        super().__init__(loc=loc, parent=parent)
         self.mutability = mutability
         self.scope = scope
         self.visibility = visibility
@@ -54,15 +58,13 @@ class VariableDeclaration(StatementType):
     def __str__(self) -> str:
         """Return a string that represents the object."""
         type_ = self.type_.__name__
-        return f"VariableDeclaration[{self.name}, {type_}] = {self.value}"
+        return f"VariableDeclaration[{self.name}, {type_}]"
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Return a string that represents the object."""
-        type_ = self.type_.__name__
-        struct_key = (
-            f"VariableDeclaration[{self.name}, {type_}] = {self.value}"
-        )
-        return cast(ReprStruct, {struct_key: self.value})
+        key = str(self)
+        value = self.value.get_struct(simplified)
+        return self._prepare_struct(key, value, simplified)
 
 
 @public
@@ -86,10 +88,11 @@ class InlineVariableDeclaration(Expr):
         visibility: VisibilityKind = VisibilityKind.public,
         scope: ScopeKind = ScopeKind.local,
         value: Expr = UNDEFINED,
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
     ) -> None:
         """Initialize the VarExprAST instance."""
-        self.loc = loc
+        super().__init__(loc=loc, parent=parent)
         self.mutability = mutability
         self.scope = scope
         self.visibility = visibility
@@ -101,15 +104,13 @@ class InlineVariableDeclaration(Expr):
     def __str__(self) -> str:
         """Return a string that represents the object."""
         type_ = self.type_.__name__
-        return f"VariableDeclaration[{self.name}, {type_}] = {self.value}"
+        return f"InlineVariableDeclaration[{self.name}, {type_}]"
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Return a string that represents the object."""
-        type_ = self.type_.__name__
-        struct_key = (
-            f"VariableDeclaration[{self.name}, {type_}] = {self.value}"
-        )
-        return cast(ReprStruct, {struct_key: self.value})
+        key = str(self)
+        value = self.value.get_struct(simplified)
+        return self._prepare_struct(key, value, simplified)
 
 
 @public
@@ -123,9 +124,11 @@ class VariableAssignment(StatementType):
         self,
         name: str,
         value: Expr,
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
     ) -> None:
         """Initialize the VarExprAST instance."""
+        super().__init__(loc=loc, parent=parent)
         self.loc = loc
         self.name = name
         self.value = value
@@ -133,12 +136,13 @@ class VariableAssignment(StatementType):
 
     def __str__(self) -> str:
         """Return a string that represents the object."""
-        return f"VariableAssignment[{self.name}] = {self.value}"
+        return f"VariableAssignment[{self.name}]"
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Return a string that represents the object."""
-        struct_key = f"VariableAssignment[{self.name}] = {self.value}"
-        return cast(ReprStruct, {struct_key: self.value})
+        key = str(self)
+        value = self.value.get_struct(simplified)
+        return self._prepare_struct(key, value, simplified)
 
 
 @public
@@ -150,19 +154,22 @@ class Variable(DataTypeOps):
     def __init__(
         self,
         name: str,
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
     ) -> None:
         """Initialize the Variable instance."""
-        super().__init__(loc)
+        super().__init__(loc=loc, parent=parent)
         self.name = name
 
     def __str__(self) -> str:
         """Return a string that represents the object."""
         return f"Variable[{self.name}]"
 
-    def get_struct(self) -> ReprStruct:
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
         """Return a string that represents the object."""
-        return cast(ReprStruct, {f"Variable[{self.name}]": self})
+        key = f"Variable[{self.name}]"
+        value = self.name
+        return self._prepare_struct(key, value, simplified)
 
 
 @public
@@ -180,17 +187,48 @@ class Argument(Variable):
         type_: ExprType,
         mutability: MutabilityKind = MutabilityKind.constant,
         default: Expr = UNDEFINED,
-        loc: SourceLocation = SourceLocation(0, 0),
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
     ) -> None:
         """Initialize the VarExprAST instance."""
-        self.loc = loc
+        super().__init__(name=name, loc=loc, parent=parent)
         self.mutability = mutability
-        self.name = name
         self.type_ = type_
         self.default = default
         self.kind = ASTKind.ArgumentKind
 
-    def get_struct(self) -> ReprStruct:
+    def __str__(self) -> str:
         """Return a string that represents the object."""
-        struct_key = f"Argument[{self.name}, {self.type_}] = {self.default}"
-        return cast(ReprStruct, {struct_key: self.default})
+        type_ = self.type_.__name__
+        return f"Argument[{self.name}, {type_}]"
+
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
+        """Return a string that represents the object."""
+        key = f"Argument[{self.name}, {self.type_}] = {self.default}"
+        value = cast(ReprStruct, self.default)
+        return self._prepare_struct(key, value, simplified)
+
+
+@public
+class Arguments(ASTNodes):
+    """AST class for argument definition."""
+
+    def __init__(self, *args: Argument, **kwargs: Any) -> None:
+        super().__init__(**kwargs)
+        for arg in args:
+            self.append(arg)
+
+    def __str__(self) -> str:
+        """Return a string that represents the object."""
+        return f"Arguments({len(self.nodes)})"
+
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
+        """Return a string that represents the object."""
+        args_nodes = []
+
+        for node in self.nodes:
+            args_nodes.append(node.get_struct(simplified))
+
+        key = str(self)
+        value = cast(ReprStruct, args_nodes)
+        return self._prepare_struct(key, value, simplified)
